package NorisOtrsReport::Processor;

use Moose;
use NorisOtrsReport::JSONRenderer;

has 'Renderer' => (is => 'ro', default => sub { NorisOtrsReport::JSONRenderer->new() }, isa => 'NorisOtrsReport::Renderer');

sub start {
    my ($Self) = @_;
    $Self->{Renderer}->start();
}

sub start_search {
    my ($Self) = @_;
    $Self->{Renderer}->start_search();
}

sub finish_search {
    my ($Self) = @_;
    $Self->{Renderer}->finish_search();
}

sub finish {
    my ($Self) = @_;
    $Self->{Renderer}->finish();
}

1;
